UpdateAvailability enum
Values
- unknown → const UpdateAvailability
-
const UpdateAvailability(UPDATE_AVAILABILITY_UNKNOWN, 'Update availability is unknown.') - notAvailable → const UpdateAvailability
-
const UpdateAvailability(UPDATE_AVAILABILITY_NOT_AVAILABLE, 'No update is available.') - available → const UpdateAvailability
-
const UpdateAvailability(UPDATE_AVAILABILITY_AVAILABLE, 'An update is available or already downloaded.') - inProgress → const UpdateAvailability
-
const UpdateAvailability(UPDATE_AVAILABILITY_IN_PROGRESS, 'Update download or installation is already in progress.')
Properties
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- value → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
fromValue(
int value) → UpdateAvailability
Constants
-
values
→ const List<
UpdateAvailability> - A constant List of the values in this enum, in order of their declaration.