RequestResponse class

Available extensions

Constructors

RequestResponse({required int bytesDownloaded, required int installErrorCode, required int installStatus, required String packageName, required int totalBytesToDownload})

Properties

bytesDownloaded int
getter/setter pair
downloadProgress double?

Available on RequestResponse, provided by the RequestResponseX extension

no setter
hashCode int
The hash code for this object.
no setterinherited
installError RustoreUpdateError

Available on RequestResponse, provided by the RequestResponseX extension

no setter
installErrorCode int
getter/setter pair
installStatus int
getter/setter pair
installStatusValue InstallStatus

Available on RequestResponse, provided by the RequestResponseX extension

no setter
packageName String
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
totalBytesToDownload int
getter/setter pair

Methods

encode() Object
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

decode(Object result) RequestResponse